@@ -1,4 +1,4 @@
-/*      $Id: events.c,v 1.239 2004/08/22 22:18:50 olivier Exp $
+/*      $Id: events.c,v 1.241 2004/08/24 05:58:06 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -1204,7 +1204,7 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
             if ((c->win_workspace == screen_info->current_ws) || 
                 (FLAG_TEST (c->flags, CLIENT_FLAG_STICKY)))
             {
-                if (FLAG_TEST (c->flags, CLIENT_FLAG_HIDDEN))
+                if (FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
                 {
                     clientShow (c, TRUE);
                 }
@@ -1554,7 +1554,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         if ((ev->message_type == wm_change_state) && (ev->format == 32) && (ev->data.l[0] == IconicState))
         {
             TRACE ("client \"%s\" (0x%lx) has received a wm_change_state event", c->name, c->window);
-            if (!FLAG_TEST (c->flags, CLIENT_FLAG_HIDDEN) && 
+            if (!FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED) && 
                  CLIENT_CAN_HIDE_WINDOW (c))
             {
                 clientHide (c, c->win_workspace, TRUE);
@@ -1571,7 +1571,6 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             if ((ev->data.l[0] != c->win_layer) && !clientIsTransientOrModal (c))
             {
                 clientSetLayer (c, ev->data.l[0]);
-                clientSetNetState (c);
             }
         }
         else if ((ev->message_type == win_workspace) && (ev->format == 32))
@@ -1936,7 +1935,7 @@ show_popup_cb (GtkWidget * widget, GdkEventButton * ev, gpointer data)
             }
         }
 
-        if (FLAG_TEST (c->flags, CLIENT_FLAG_HIDDEN))
+        if (FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
         {
             ops |= MENU_OP_UNMINIMIZE;
             if (!CLIENT_CAN_HIDE_WINDOW (c))
