@@ -1,4 +1,4 @@
-/*      $Id: session.c,v 1.20 2004/08/22 22:18:50 olivier Exp $
+/*      $Id: session.c,v 1.21 2004/08/24 05:58:06 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -339,7 +339,7 @@ sessionSaveScreen (ScreenInfo *screen_info, FILE *f)
         fprintf (f, "  [SCREEN] %i\n", screen_info->screen);
         fprintf (f, "  [DESK] %i\n", c->win_workspace);
         fprintf (f, "  [FLAGS] 0x%lx\n", FLAG_TEST (c->flags,
-                CLIENT_FLAG_STICKY | CLIENT_FLAG_HIDDEN |
+                CLIENT_FLAG_STICKY | CLIENT_FLAG_ICONIFIED |
                 CLIENT_FLAG_SHADED | CLIENT_FLAG_MAXIMIZED |
                 CLIENT_FLAG_NAME_CHANGED));
     }
@@ -670,7 +670,7 @@ sessionMatchWinToSM (Client * c)
             FLAG_SET (c->flags,
                 matches[i].
                 flags & (CLIENT_FLAG_STICKY | CLIENT_FLAG_SHADED |
-                    CLIENT_FLAG_MAXIMIZED | CLIENT_FLAG_HIDDEN));
+                    CLIENT_FLAG_MAXIMIZED | CLIENT_FLAG_ICONIFIED));
             FLAG_SET (c->flags, CLIENT_FLAG_WORKSPACE_SET);
             return TRUE;
         }
