@@ -1,4 +1,4 @@
-/*      $Id: stacking.c,v 1.18 2004/08/22 22:18:50 olivier Exp $
+/*      $Id: stacking.c,v 1.19 2004/08/24 05:58:06 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ clientTransientOrModalHasAncestor (Client * c, int ws)
         c2 = (Client *) index->data;
         if ((c2 != c) && !clientIsTransientOrModal (c2)
             && clientIsTransientOrModalFor (c, c2)
-            && !FLAG_TEST (c2->flags, CLIENT_FLAG_HIDDEN)
+            && !FLAG_TEST (c2->flags, CLIENT_FLAG_ICONIFIED)
             && (c2->win_workspace == ws))
         {
             return TRUE;
